==> xmonad-extras-0.17.2-171-loong64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-8QZOhEGg3MO51qzpnczaN7
key:                  xmonad-extras-0.17.2-8QZOhEGg3MO51qzpnczaN7
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  a6f8508a294aabfcf87144fca453462f
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-8QZOhEGg3MO51qzpnczaN7
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    alsa-mixer-0.3.0.1-D5NqpzQN3mDH3TSCPqK4Sy base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-INvnWTkkmrECqNpDSboXTA
    hint-0.9.0.8-9ZLqnKbXnXu19br7AITIs8
    libmpd-0.10.0.1-KP9sAQGTWuvKXnknyUi3fo mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF
    xmonad-0.18.0-7ncefdvtZDKFFjo51IQreA
    xmonad-contrib-0.18.1-54g7n5a73HEx91kIZfNWc

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-173-loong64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-9N9wDd5PaAgJV4yyYqupXd
key:                  xmonad-extras-0.17.2-9N9wDd5PaAgJV4yyYqupXd
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  43195b4b32c1ec5a2c7f0508d889ba84
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-9N9wDd5PaAgJV4yyYqupXd
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    alsa-mixer-0.3.0.1-D5NqpzQN3mDH3TSCPqK4Sy base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-G1Ov6W8p6PCE1zpW2NkSy4
    hint-0.9.0.8-9a5UKWJLJN5GBPqxA4TOpA
    libmpd-0.10.0.1-KBSvWrNoUQAFL1xDg87S33 mtl-2.3.1
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF
    xmonad-0.18.0-3LONdRo13bQAmJZdbYdp3W
    xmonad-contrib-0.18.1-CaEVvUm0vCsBfGtHRX98IN

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
